"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const command_1 = require("@oclif/command");
const path = require("path");
const child_process_1 = require("child_process");
const utils_1 = require("../utils");
class Init extends command_1.Command {
    constructor() {
        super(...arguments);
        this.handleError = (e) => {
            if (e) {
                this.error(`Failed to init repository.
        ${e.message}`);
            }
        };
        this.command = (cmd) => new Promise((resolve, reject) => {
            child_process_1.exec(cmd, (e, stdout, stderr) => {
                if (e) {
                    reject(e);
                }
                else
                    resolve();
            });
        });
    }
    async run() {
        const { args, flags } = this.parse(Init);
        // const name = flags.name ?? 'world'
        this.log(`Initializing git repo at ${path.resolve("./")}`);
        await this.command("git init").catch(this.handleError);
        // fs.copyFileSync(
        //   path.resolve(__root, "files/gitignore"),
        //   path.resolve("./.gitignore")
        // );
        // fs.copyFileSync(
        //   path.resolve(__root, "files/gitattributes"),
        //   path.resolve("./.gitattributes")
        // );
        this.log("Downloading .gitignore");
        await utils_1.download(`${utils_1.__repo}/gitignore`, path.resolve("./.gitignore")).catch(this.handleError);
        this.log("Downloading .gitattributes");
        await utils_1.download(`${utils_1.__repo}/gitattributes`, path.resolve("./.gitattributes")).catch(this.handleError);
        this.log("Initializing git lfs");
        await this.command("git lfs install").catch(this.handleError);
    }
}
exports.default = Init;
Init.description = "init a new git repository for your unity project.";
Init.examples = [`$ unity-git init`];
Init.flags = {
// help: flags.help({char: 'h'}),
// // flag with a value (-n, --name=VALUE)
// name: flags.string({char: 'n', description: 'name to print'}),
// // flag with no value (-f, --force)
// force: flags.boolean({char: 'f'}),
};
Init.args = [];
